@@ -13,17 +13,11 @@ OC.L10N.register(
     "News" : "Новини",
     "An RSS/Atom feed reader" : "Четец за RSS/Atom емисии",
     "Use system cron for updates" : "Използване на системния cron за актуализации",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Изключете функцията ако ползвате свое собствено приложение за обновяване като Python приложението включено в тази програма",
     "Purge interval" : "Интервал за изтриване",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Минимално време в секунди, след което изтрити емисии и папки биват премахвани от базата данни; стойности под 60 секунди ще бъдат игнорирани",
     "Maximum read count per feed" : "Максимален брой прочитания на емисия",
     "Maximum redirects" : "Максимален брой пренасочвания",
-    "How many redirects the feed fetcher should follow" : "До колко пренасочвания да бъдат последвани, преди да бъде прекратено индексирането на емисията",
     "Maximum feed page size" : "Максимален размер на страница от емисия",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Максимален размер на емисия в байтове. Ако RSS/Atom страницата е по-голяма от тази стойност, актуализирането се прекратява",
     "Feed fetcher timeout" : "Максимално време за изчакване",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Максималното време в секунди за изчакване зареждането на RSS или Atom емисия; ако отнема по-дълго актуализирането се прекратява",
-    "For more information check the wiki" : "За допълнителна информация проверете wiki страницата",
     "Saved" : "Запазено",
     "Download" : "Изтегли",
     "Close" : "Затваряне",
