@@ -12,20 +12,12 @@ OC.L10N.register(
     "Can not add folder: Exists already" : "Kan ikke tilføje mappe: Den findes allerede",
     "News" : "Nyheder",
     "Use system cron for updates" : "Benyt system cron til opdateringer",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Slå denne fra, hvis du kører en brugerdefineret opdateringsfunktion såsom Pythons opdateringsfunktion som indgår i app'en",
     "Purge interval" : "Oprydningsinterval",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Den korteste varighed i sekunder før slettede feeds og mapper bliver fjernet fra databasen; værdier under 60 sekunder bliver ignoreret",
     "Maximum read count per feed" : "Det maksimale antal læsninger per feed",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Definer det maksimale antal artikler der kan læses pr. feed uden at det bliver slettet af oprydningsjobbet. Hvis gamle artikler dukker op efter de er læst så prøv at gøre tallet større. Hvis tallet er negativt vil slå featuren fra.",
     "Maximum redirects" : "Maksimum for videredirigeringer",
-    "How many redirects the feed fetcher should follow" : "Hvor mange videredirigeringer som feed-indhenteren skal følge",
     "Maximum feed page size" : "Maksimal størrelse for feed-side",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maksimum for feed-størrelse i bytes. Hvis RSS/Atom-siden er større end denne værdi, så afbrydes opdateringen",
     "Feed fetcher timeout" : "Tidsudløb for feed-indhenter",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Det maksimale antal ventetid målt i sekunder for indlæsning af et RSS- eller Atom-feed; hvis det tager længere tid, så afbrydees opdateringen",
     "Explore Service URL" : "Udforsk tjenestens URL",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Hvis denne angives, så vil tjenestens URL blive forespurgt om visning af feeds in sektionen udforsk feed. For at falde tilbage på den indbyggede udforskningstjeneste, så lad feltet stå tomt",
-    "For more information check the wiki" : "For mere information tjek wikien.",
     "Saved" : "Gemt",
     "Download" : "Download",
     "Close" : "Luk",
