@@ -13,20 +13,12 @@ OC.L10N.register(
     "News" : "Noticias",
     "An RSS/Atom feed reader" : "Un lector de fuentes RSS/Atom",
     "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Deshabilita esto si usas un actualizador personalizado como el actualizador de Python en la aplicación",
     "Purge interval" : "Intervalo de purga",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Número mínimo de segundos a esperar antes de eliminar de la base de datos carpetas y fuentes borrados; valores inferiores a 60 segundos son ignorados",
     "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Define el número máximo de artículos que pueden ser leídos por fuente que no serán borrados por el trabajo de limpieza; si reaparecen artículos anteriores después de ser leídos, incrementa este valor; valores negativos tales como -1 desactivarán esta funcionalidad. ",
     "Maximum redirects" : "Redirecciones máximas",
-    "How many redirects the feed fetcher should follow" : "Cuantas redirecciones debería seguir el buscador de fuentes",
     "Maximum feed page size" : "Tamaño máximo de la página de la fuente",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Tamaño máximo de una fuente en bytes. Si la página RSS/Atom es mayor a este valor, la actualización será abortada ",
     "Feed fetcher timeout" : "Tiempo de vida para el buscador de fuentes",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Número máximo de segundos a esperar a que cargue una fuente RSS o Atom; si toma más tiempo, será abortada",
     "Explore Service URL" : "Explorar la URL del Servicio",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Si es proporcionado, la URL de este servicio será consultada para desplegar las fuentes en la seccion de explorar fuente. Para regresar al servicio integrado de exploración, déjalo vacío",
-    "For more information check the wiki" : "Para más información consulta el wiki",
     "Saved" : "Guardado",
     "Download" : "Descargar",
     "Close" : "Cerrar",
