@@ -10,18 +10,12 @@ OC.L10N.register(
     "Can not add folder: Exists already" : "Kausta ei saa lisada: on juba olemas",
     "News" : "News",
     "Use system cron for updates" : "Kasuta süsteemi croni uuendusteks",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Keela see kui sa kasutada kohandatud uuendajat nagu rakendites olevat Python updater-it",
     "Purge interval" : "Puhastuse intervall",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Maksimaalne aeg sekundites peale mida voog ja kataloogid eemaldatakse andmebaasist; väärtusi alla 60 sekundi ignoreeritakse",
     "Maximum read count per feed" : "Maksimaalne lugemiste arv voo kohta",
     "Maximum redirects" : "Maksimaalsed ümbersuunamised",
-    "How many redirects the feed fetcher should follow" : "Kui palju ümbersuunamisi peaks voo uuendaja järgima",
     "Maximum feed page size" : "Maksimaalne voo lehekülje suurus",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maksimaalne voo suurus baitides. Kui RSS/Atom lehekülg on suurem kui see väärtus, siis uuendamine katkestatakse",
     "Feed fetcher timeout" : "Voo ühenduse aegumine",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maksimaalne aeg sekundites RSS või Atom voo laadimiseks; kui see võtab kauem, siis uuendus katkestatakse",
     "Explore Service URL" : "Sirvi teenuse URL-i",
-    "For more information check the wiki" : "Et saada rohkem infot, vaata wikisse",
     "Saved" : "Salvestatud",
     "Download" : "Lae alla",
     "Close" : "Sulge",
