@@ -13,15 +13,11 @@ OC.L10N.register(
     "News" : "Uutiset",
     "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
     "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Poista käytöstä, jos käytät omavalintaista päivitystapaa, kuten sovelluksen mukana tullutta Python-päivitystapaa",
     "Purge interval" : "Hävitysväli",
     "Maximum read count per feed" : "Syötekohtaisten lukukertojen enimmäismäärä",
     "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
-    "How many redirects the feed fetcher should follow" : "Kuinka montaa uudelleenohjausta noutajan tulisi seurata",
     "Maximum feed page size" : "Syötteen sivun enimmäiskoko",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Syötteen enimmäiskoko tavuissa. Jos RSS-/Atom-sivu on tätä arvoa suurempi, päivitys perutaan",
     "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "RSS- tai Atom-syötteen latautumisen odotuksen enimmäisaika; jos latautuminen kestää enemmän kuin enimmäisajan, päivitys perutaan",
     "Saved" : "Tallennettu",
     "Download" : "Lataa",
     "Close" : "Sulje",
