@@ -12,20 +12,12 @@ OC.L10N.register(
     "Can not add folder: Exists already" : "დირექტორიის დამატება შეუძლებელია: უკვე არსებობს",
     "News" : "სიახლეები",
     "Use system cron for updates" : "განახლებისთვის გამოიყენეთ სისტემური კრონი",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "გათიშეთ თუ იყენებთ პერსონალურ განმანახლებელს როგორიცაა აპლიკაციაში შეტანილი Python updater-ი",
     "Purge interval" : "გაწმენდის ინტერვალი",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "წამების მინიმალური ოდენობა გაუქმებული ლენტებისა და დირექტორიების მონაცემთა ბაზიდან წაშლისთვის; მნიშვნელობები 60 წამს ქვემოთ იგნორირებულია.",
     "Maximum read count per feed" : "თითო ლენტაზე მაქისმალური კითხვის რაოდენობა",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "საზღვრავს არტიკლების მაქსიმალურ რაოდენობას, რომლებიც შეიძლება წაკითხულ იქნას თოთო ლენტაზე, რომელიც არ იქნება გასუფთავების ფუნქციონალით წაშლილი; თუ ძველი არტიკლი ჩნდება მის წაკითხვის შემდეგ, გაზარდეთ ეს მნიშვნელობა; უარყოფით მნიშვნელობები როგორებიცაა -1 ამ ფუნქცას გათიშავს",
     "Maximum redirects" : " მაქს. გადამისამართებები",
-    "How many redirects the feed fetcher should follow" : "რამდენი გადამისამართება უნდა დაუშვას ლენტის მომპოვებელმა",
     "Maximum feed page size" : "ლენტის გვერდის მაქს. ზომა",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "ლენტის მაქს. ზომა ბაიტებში. თუ RSS/Atom გვერდი თავის მნიშვნელობაზე დიდია, განახლება შეჩერდება",
     "Feed fetcher timeout" : "ლენტის მომპოვებლის დროის ამოწურვა",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "წამის მაქს. ოდენობა RSS ან Atom ლენტის ჩატვირთვისთვის ლოდინისთვის; თუ დრო გასტანს მეტ ხანს განახლება შეჩერდება",
     "Explore Service URL" : "სერვის მისამართის დათვალიერება",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "თუ მოცემულია სერვისის მისამართი განიხილება ლენტის მიმოხილვის სექციაში გამოსაჩენად. იმისათვის რომ ამ პარამეტრს მიანიჭოთ საწყისი მნიშვნელობა დატოვეთ ველი ცარიელი",
-    "For more information check the wiki" : "მეტი ინფორმაციისთვის იხილეთ ვიკი",
     "Saved" : "შენახულია",
     "Download" : "ჩამოტვირთვა",
     "Close" : "დახურვა",
