@@ -13,20 +13,12 @@ OC.L10N.register(
     "News" : "Nyheter",
     "An RSS/Atom feed reader" : "En RSS/Atom-leser",
     "Use system cron for updates" : "Bruk system-cron for oppdateringer",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Deaktiver dette hvis du kjører en tilpasset oppdaterer, som f.eks. Python-opdatereren som er inkludert i appen",
     "Purge interval" : "Opprenskingsinterval",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minste antall sekunder etter at slettede strømmer og mapper er fjernet fra databasen; verdier under 60 sekunder ignoreres",
     "Maximum read count per feed" : "Maksimalt antall lest pr. strøm",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Definerer maksimalt antall artikler som kan leses pr. strøm som ikke vil bli slettet av opprenskningsjobben. Hvis gamle artikler dukker opp igjen etter at de er lest, øk denne verdien. Negative verdier, som -1, vil slå av denne funksjonen",
     "Maximum redirects" : "Maksimalt antall videresendinger",
-    "How many redirects the feed fetcher should follow" : "Hvor mange videresendinger som skal følges ved henting av strøm",
     "Maximum feed page size" : "Maksimal størrelse på strøm",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maksimal strømstørrelse i byte. Hvis RSS/Atom-siden er større enn dette, avbrytes oppdateringen",
     "Feed fetcher timeout" : "Tidsavbrudd for henting av strøm",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maksimalt antall sekunder venting på at en RSS- eller Atom-strøm skal bli lastet. Hvis det tar lenger tid, avbrytes oppdateringen",
     "Explore Service URL" : "URL for utforskertjeneste",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Hvis oppgitt, vil denne tjenestens nettadresse bli forespurt for visning av strømmer i seksjonen for utforsking av strømmer. La stå tomt for å falle tilbake på den innebygde utforsker-tjenesten.",
-    "For more information check the wiki" : "Sjekk wiki-en for mer informasjon",
     "Saved" : "Lagret",
     "Download" : "Last ned",
     "Close" : "Lukk",
