@@ -8,18 +8,12 @@ OC.L10N.register(
     "Can not add feed: Exists already" : "Impossible d'apondre lo flux : ja present",
     "Articles without feed" : "Articles sens flux",
     "Can not add folder: Exists already" : "Impossible d'apondre lo dorsièr : ja present",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Desactivar aquò se utilizatz un logicial de mesa a jorn particular tal coma lo logicial de mesa a jorn Python inclús dins l'aplicacion",
     "Purge interval" : "Interval de purga",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Nombre minimum de segondas aprèp lo qual los fluxes e dorsièrs suprimits seràn escafats de la banca de donadas. Las valors inferioras a 60 segondas seràn ignoradas.",
     "Maximum read count per feed" : "Nombre maximum de lectura per flux",
     "Maximum redirects" : "Nombre maximal de redireccions",
-    "How many redirects the feed fetcher should follow" : "Nombre de redireccions que lo recuperador de flux deu seguir",
     "Maximum feed page size" : "Talha maximum de pagina de flux",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Talha maximum de flux en octets. Se la talha de la pagina RSS/Atom depassa aquesta valor, la mesa a jorn serà abandonada.",
     "Feed fetcher timeout" : "Relambi d'espèra maximum del recuperador de flux",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Nombre maximal de segondas que pòt préner un flux RSS o Atom per èsser cargat. Se lo relambi es depassat, la mesa a jorn serà anullada",
     "Explore Service URL" : "URL del servici d'exploracion",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Se indicada, l'URL d'aqueste servici serà interrogada per afichar los fluxes dins la seccion \"Explorar\". Per tornar al servici d'exploracion per defaut, daissatz aqueste camp void.",
     "Saved" : "Salvat",
     "Download" : "Telecargar",
     "Close" : "Tampar",
