@@ -8,18 +8,12 @@ OC.L10N.register(
     "Can not add feed: Exists already" : "Não é possível adicionar o feed: Já existe",
     "Articles without feed" : "Artigos sem feed",
     "Can not add folder: Exists already" : "Não é possível adicionar a pasta: Já existe",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Desative isto se estiver a utilizar um atualizador personalizado, tal como, o atualizador Python incluído na app",
     "Purge interval" : "Intervalo de Purgar",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Número mínimo de segundos depois de remover os feeds e as pastas da base de dados; os valores abaixo de 60 segundos são ignorados",
     "Maximum read count per feed" : "Número máximo de leituras por feed",
     "Maximum redirects" : "Máximo de redirecionamentos",
-    "How many redirects the feed fetcher should follow" : "Quantos redirecionamentos é que o 'obter feed' deverá seguir",
     "Maximum feed page size" : "Tamanho máximo da página feed",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Tamanho máximo da feed em bytes. Se a página RSS/Atom for maior do que este valor, a atualização será abortada",
     "Feed fetcher timeout" : "A obtenção do feed expirou",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Número máximo de segundos a esperar por feed RSS ou Atom para carregar; se demorar desmasiado, a actualização será cancelada",
     "Explore Service URL" : "Explorar Serviço URL",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Se autorizado, este serviço URL será consultado para mostrar os feeds na secção de exploração de feeds. Para voltar ao serviço de exploração anterior, deixe isto vazio",
     "Saved" : "Guardado",
     "Download" : "Transferir",
     "Close" : "Fechar",
