@@ -46,6 +46,9 @@ OC.L10N.register(
     "Undo delete feed" : "Anulează ștergerea fluxului",
     "Rename" : "Redenumește",
     "Menu" : "Meniu",
+    "Newest first" : "Cel mai nou mai întâi",
+    "Oldest first" : "Cel mai vechi mai întâi",
+    "Delete" : "Șterge",
     "Dismiss" : "Înlătură",
     "Collapse" : "Restrânge",
     "Deleted folder" : "Director șters",
