@@ -14,19 +14,12 @@ OC.L10N.register(
     "News" : "Novice",
     "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
     "Use system cron for updates" : "Za posodobitve uporabi sistemski program »cron«",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Možnost onemogočite, če uporabljate posodabljalnik po meri, kot je na primer posodabljalnik Python, vključen v programski paket",
     "Purge interval" : "Časovni razmik odstranjevanja",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Najkrajši čas, po katerem bodo viri in mape odstranjeni iz podatkovne zbirke. Vrednosti pod 60 sekundami so prezrte.",
     "Maximum read count per feed" : "Največje število prikazanih virov",
     "Maximum redirects" : "Največje število preusmeritev",
-    "How many redirects the feed fetcher should follow" : "Koliko preusmeritvam naj sledi bralnik virov",
     "Maximum feed page size" : "Največja velikost strani vira",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Največja dovoljena velikost vira v bajtih. Če je vir RSS/ATOM večji od te vrednosti, bo posodobitev prekinjena.",
     "Feed fetcher timeout" : "Čas nalaganja vira",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Čas, namenjen nalaganju virov RSS in Atom. Po tem času je nalaganje virov prekinjeno.",
     "Explore Service URL" : "Razišči spletni naslov storitve",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Če je podan, bo prek tega naslova URL storitve potekala poizvedba za vire in njihov i zbor. Za preklop v vgrajeno storitev določevanja, mora biti polje prazno.",
-    "For more information check the wiki" : "Za več podrobnosti obiščite Wiki",
     "Saved" : "Shranjeno",
     "Download" : "Prejmi",
     "Close" : "Zapri",
