@@ -14,20 +14,12 @@ OC.L10N.register(
     "News" : "Nyheter",
     "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
     "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Inaktivera detta om du använder en anpassad uppdaterare så som Python-uppdateraren som ingår i appen",
     "Purge interval" : "Utrensningsintervall",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minimum antal sekunder efter det att borttagna flöden och mappar tas bort från databasen; värden under 60 sekunder ignoreras",
     "Maximum read count per feed" : "Maximalt läsantal per flöde",
-    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Definiera maximalt antal artiklar som kan läsas per flöde som inte blir borttaget av uppstädningen; om gamla artiklar återuppstår när de lästs, öka detta värde; negativa värden som -1 stänger av funktionen",
     "Maximum redirects" : "Maximala omdirigeringar",
-    "How many redirects the feed fetcher should follow" : "Hur många omdirigeringar flödet skall tillåtas följa",
     "Maximum feed page size" : "Maximum storlek på flödessidan",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximum storlek på flödet i bytes. Om RSS/Atom sidan är större än detta värde, kommer uppdateringen att avbrytas.",
     "Feed fetcher timeout" : "Timeout för flödes-hämtare",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximalt antal sekunder att vänta på att RSS/Atom-flödet läses in; om det tar längre tid avbryts uppdateringen.",
     "Explore Service URL" : "Utforska tjänstwebbadress",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Om angiven kommer denna tjänsts webbadress bli förfrågad om visning av flöden i flödet för utforskarsektionen. För att falla tillbaks på den inbyggda utforskar tjänsten, lämna detta inmatningsfält tomt\n\nOm detta anges kommer den här tjänstens webbadress att bli förfrågad av visning av flöden i avsnittet utforska flödet. För att återgå till den inbyggda utforskartjänsten, lämna det här inmatningsfältet tomt",
-    "For more information check the wiki" : "För mer information, se wiki.",
     "Saved" : "Sparad",
     "Download" : "Hämta",
     "Close" : "Stäng",
@@ -85,7 +77,7 @@ OC.L10N.register(
     "Create" : "Skapa",
     "Explore" : "Utforska",
     "Update failed more than 50 times" : "Uppdatering misslyckades mer än 50 gånger",
-    "Deleted feed" : "Raderade flöde",
+    "Deleted feed" : "Borttagna flöde",
     "Undo delete feed" : "Ångra radera flöde",
     "Rename" : "Byt namn",
     "Menu" : "Meny",
