@@ -8,18 +8,12 @@ OC.L10N.register(
     "Can not add feed: Exists already" : "ไม่สามารถเพิ่มฟีด: มันมีอยู่แล้ว",
     "Articles without feed" : "บทความไม่มีฟีด",
     "Can not add folder: Exists already" : "ไม่สามารถเพิ่มโฟลเดอร์: มีอยู่แล้ว",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "ปิดการใช้งานนี้ถ้าคุณเรียกใช้อัพเดทด้วยตนเองเช่นอัพเดท Python รวมอยู่ในแอพฯ",
     "Purge interval" : "ช่วงเวลาที่ล้าง",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "จำนวนขั้นต่ำของวินาทีหลังจากลบฟีดและโฟลเดอร์ที่ถูกลบออกจากฐานข้อมูลนั้น ค่าต่ำกว่า 60 วินาทีจะถูกยกเว้น",
     "Maximum read count per feed" : "นับจำนวนอ่านสูงสุดต่อฟีด",
     "Maximum redirects" : "เปลี่ยนเส้นทางสูงสุด",
-    "How many redirects the feed fetcher should follow" : "กี่เส้นทางที่ตัวเรียกฟีดควรติดตาม",
     "Maximum feed page size" : "ขนาดหน้าฟีดสูงสุด",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "ขนาดฟีดสูงสุดเป็นไบต์ หากหน้า RSS/Atom มีขนาดใหญ่กว่าค่านี้การอัพเดทจะถูกยกเลิก",
     "Feed fetcher timeout" : "ตัวเรียกฟีดหมดเวลา",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "จำนวนวินาทีสูงสุดของ RSS หรือ Atom เพื่อรอโหลดฟีด ถ้ามันใช้เวลานานในการอัพเดทจะถูกยกเลิก",
     "Explore Service URL" : "สำรวจบริการ URL",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "หากได้รับบริการ URL นี้ คุณจะได้รับการสอบถามการสำรวจการแสดงของฟีด ปล่อยว่างไว้หากคุณไม่ต้องการมัน",
     "Saved" : "บันทึกแล้ว",
     "Download" : "ดาวน์โหลด",
     "Close" : "ปิด",
