@@ -24,4 +24,4 @@ OC.L10N.register(
     "Help" : "ياردەم",
     "Documentation" : "قوللانما"
 },
-"nplurals=1; plural=0;");
+"nplurals=2; plural=(n != 1);");
