@@ -8,18 +8,12 @@ OC.L10N.register(
     "Can not add feed: Exists already" : "Неможливо додати стрічку: вона вже існує",
     "Articles without feed" : "Статті без стрічки",
     "Can not add folder: Exists already" : "Неможливо додати теку: вона вже існує",
-    "Disable this if you run a custom updater such as the Python updater included in the app" : "Вимкніть, якщо збираєтеся використовувати інший механізм оновлень, наприклад, Python updater, включений в поставку цього додатка",
     "Purge interval" : "Очистити оновлення",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Мінімальна кількість секунд, після чого стрічки й каталоги, які було вилучено, буде вилучено з бази даних; значення менш ніж 60 секунд буде проігноровано",
     "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
     "Maximum redirects" : "Максимум перенаправлень",
-    "How many redirects the feed fetcher should follow" : "Скільки перенаправлень повинен обробляти завантажувач стрічки",
     "Maximum feed page size" : "Максимальний розмір сторінки для стрічки",
-    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Максимальний розмір стрічки в байтах. Якщо розмір сторінки RSS/Atom більше цього значення, оновлення буде скасовано",
     "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
-    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Максимальна кількість секунд очікування завантаження стрічки RSS або Atom; якщо оновлення займає більше часу, то воно буде скасовано",
     "Explore Service URL" : "URL сервісу дослідження",
-    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Якщо зазначено, то URL сервісу опитуватиметься з метою відображення стрічок в секції дослідження. Для повернення до вбудованого сервісу, залиште поле порожнім.",
     "Saved" : "Збереженно",
     "Download" : "Завантажити",
     "Close" : "Закрити",
@@ -76,6 +70,7 @@ OC.L10N.register(
     "Undo delete feed" : "Скасувати вилучення стрічки",
     "Rename" : "Перейменувати",
     "Menu" : "Меню",
+    "Mark read" : "Позначити як прочитане",
     "Newest first" : "Новіші попереду",
     "Oldest first" : "Старіші попереду",
     "Delete" : "Вилучити",
