@@ -13,7 +13,6 @@
 
 namespace OCA\News\AppInfo;
 
-use Closure;
 use FeedIo\FeedIo;
 use HTMLPurifier;
 use HTMLPurifier_Config;
@@ -40,7 +39,6 @@ use OCA\News\Db\ItemMapper;
 use OCA\News\Fetcher\FeedFetcher;
 use OCA\News\Fetcher\Fetcher;
 use OCA\News\Fetcher\YoutubeFetcher;
-use OCA\News\Utility\ProxyConfigParser;
 use OCA\News\Scraper\Scraper;
 
 /**
@@ -153,6 +151,20 @@ class Application extends App
                 'player.vimeo.com/video/|' .
                 'vk.com/video_ext.php)%'
             ); //allow YouTube and Vimeo
+
+            // Additionally to the defaults, allow the data URI scheme.
+            // See http://htmlpurifier.org/live/configdoc/plain.html#URI.AllowedSchemes
+            $config->set('URI.AllowedSchemes', [
+                'http' => true,
+                'https' => true,
+                'data' => true,
+                'mailto' => true,
+                'ftp' => true,
+                'nntp' => true,
+                'news' => true,
+                'tel' => true,
+            ]);
+
             $def = $config->getHTMLDefinition(true);
             $def->addAttribute('iframe', 'allowfullscreen', 'Bool');
             return new HTMLPurifier($config);
@@ -182,9 +194,6 @@ class Application extends App
             return $favicon;
         });
 
-        /**
-         * @noinspection PhpParamsInspection
-         */
         $container->registerService(Fetcher::class, function (IContainer $c): Fetcher {
             $fetcher = new Fetcher();
 
