@@ -77,9 +77,9 @@ class Item extends Entity implements IAPI, \JsonSerializable
 
     public static function fromImport($import): Item
     {
-        $item = new static();
+        $item = new Item();
         $item->setGuid($import['guid']);
-        $item->setGuidHash($import['guid']);
+        $item->setGuidHash(md5($import['guid']));
         $item->setUrl($import['url']);
         $item->setTitle($import['title']);
         $item->setAuthor($import['author']);
@@ -144,6 +144,22 @@ class Item extends Entity implements IAPI, \JsonSerializable
         return $this->enclosureLink;
     }
 
+    /**
+     * @return null|string
+     */
+    public function getMediaThumbnail()
+    {
+        return $this->mediaThumbnail;
+    }
+
+    /**
+     * @return null|string
+     */
+    public function getMediaDescription()
+    {
+        return $this->mediaDescription;
+    }
+
     /**
      * @return null|string
      */
